
<template>
  <view-grid
    ref="grid"
    :columns="columns"
    :detail="detail"
    :editFormFields="editFormFields"
    :editFormOptions="editFormOptions"
    :searchFormFields="searchFormFields"
    :searchFormOptions="searchFormOptions"
    :table="table"
    :extend="extend"
  ></view-grid>
</template>
      <script>
import extend from "@/extension/basicinfo/containerInfo.js";
import { ref, defineComponent } from "vue";
export default defineComponent({
  setup() {
    const table = ref({
      key: "id",
      footer: "Foots",
      cnName: "容器配置信息",
      name: "router",
      url: "/Container/",
      sortName: "createDate"
    });
    const editFormFields = ref({});
    const editFormOptions = ref([]);
    const searchFormFields = ref({
      containerCode: "",
      containerType: ""
    });
    const searchFormOptions = ref([
      [
        {
          title: "编码",
          field: "containerCode",
          type: "like"
        },
        {
          title: "类型",
          field: "containerType",
          type: "selectList",
          data: [
            { key: "1", value: "取货" },
            { key: "2", value: "放货" },
            { key: "3", value: "排出" },
            { key: "4", value: "异常码垛" }
          ]
        }
      ]
    ]);
    const columns = ref([
      {
        field: "id",
        title: "Id",
        type: "int",
        width: 90,
        hidden: true,
        readonly: true,
        require: true,
        align: "left"
      },
      {
        field: "containerCode",
        title: "编码",
        type: "string",
        width: 90,
        link: true,
        align: "left"
      },
      {
        field: "containerNo",
        title: "编号",
        type: "int",
        width: 90,
        align: "left"
      },
      {
        field: "containerType",
        title: "类型",
        type: "int",
        width: 90,
        align: "left",
        bind: {
          dataKey: "containerType",
          data: [
            { key: "1", value: "取货" },
            { key: "2", value: "放货" },
            { key: "3", value: "排出" },
            { key: "4", value: "异常码垛" }
          ]
        }
      },
      {
        field: "containerStatus",
        title: "状态",
        type: "int",
        width: 90,
        align: "left",
        bind: {
          dataKey: "containerStatus",
          data: [
            { key: "0", value: "空位" },
            { key: "1", value: "非空位" },
            { key: "2", value: "准备释放" },
            { key: "3", value: "释放" }
          ]
        }
      },
      {
        field: "containerLength",
        title: "长",
        type: "int",
        width: 90,
        align: "left"
      },
      {
        field: "containerWidth",
        title: "宽",
        type: "int",
        width: 90,
        align: "left"
      },
      {
        field: "containerHeight",
        title: "高",
        type: "int",
        width: 90,
        align: "left"
      },
      {
        field: "deviceCode",
        title: "设备编号",
        type: "string",
        width: 90,
        align: "left"
      },
      {
        field: "containerEnable",
        title: "是否启用",
        type: "bool",
        width: 90,
        align: "left",
        bind: {
          dataKey: "containerEnable",
          data: [
            { key: "false", value: "禁用" },
            { key: "true", value: "启用" }
          ]
        }
      },
      {
        field: "containerSort", //ContainerRemark
        title: "排序",
        type: "int",
        width: 90,
        align: "left"
      },
      {
        field: "containerRemark", //ContainerRemark
        title: "备注",
        type: "string",
        width: 90,
        align: "left"
      },
      {
        field: "creater",
        title: "创建人",
        type: "string",
        width: 90,
        align: "left"
      },
      {
        field: "createDate",
        title: "创建时间",
        type: "datetime",
        width: 160,
        align: "left"
      },
      {
        field: "modifier",
        title: "修改人",
        type: "string",
        width: 100,
        align: "left"
      },
      {
        field: "modifyDate",
        title: "修改时间",
        type: "datetime",
        width: 160,
        align: "left"
      }
    ]);
    const detail = ref({
      cnName: "容器明细信息",
      table: "Dt_ContainerItem",
      columns: [
        {
          field: "id",
          title: "Id",
          type: "int",
          width: 90,
          hidden: true,
          readonly: true,
          require: true,
          align: "left"
        },
        {
          field: "containerId",
          title: "容器主表主键",
          type: "string",
          width: 90,
          align: "left"
        },
        {
          field: "itemCode",
          title: "编号",
          type: "int",
          width: 180,
          align: "left"
        },
        {
          field: "itemName",
          title: "名称",
          type: "int",
          width: 180,
          align: "left"
        },
        {
          field: "itemLength",
          title: "长",
          type: "int",
          width: 200,
          align: "left"
        },
        {
          field: "itemWidth",
          title: "宽",
          type: "int",
          width: 120,
          align: "left"
        },
        {
          field: "itemHeight",
          title: "厚",
          type: "int",
          width: 150,
          align: "left"
        },
        {
          field: "itemPositionX",
          title: "X订单坐标",
          type: "int",
          width: 150,
          align: "left"
        },
        {
          field: "itemPositionY",
          title: "Y顶点坐标",
          type: "string",
          width: 150,
          align: "left"
        },
        {
          field: "itemPositionZ",
          title: "Z顶点坐标",
          type: "bool",
          width: 150,
          align: "left"
        },
        {
          field: "itemRelaPositionX", //ContainerRemark
          title: "X放置坐标",
          type: "int",
          width: 150,
          align: "left"
        },
        {
          field: "itemRelaPositionY", //ContainerRemark
          title: "Y放置坐标",
          type: "string",
          width: 150,
          align: "left"
        },
        {
          field: "itemRelaPositionZ", //ContainerRemark
          title: "Z放置坐标",
          type: "int",
          width: 150,
          align: "left"
        },
        {
          field: "itemStatus", //ContainerRemark
          title: "状态",
          type: "string",
          width: 150,
          align: "left"
        },
        {
          field: "remark", //ContainerRemark
          title: "备注",
          type: "string",
          width: 150,
          align: "left"
        },
        {
          field: "creater",
          title: "创建人",
          type: "string",
          width: 90,
          align: "left"
        },
        {
          field: "createDate",
          title: "创建时间",
          type: "datetime",
          width: 160,
          align: "left"
        },
        {
          field: "modifier",
          title: "修改人",
          type: "string",
          width: 100,
          align: "left"
        },
        {
          field: "modifyDate",
          title: "修改时间",
          type: "datetime",
          width: 160,
          align: "left"
        }
      ],
      sortName: "createDate",
      key: "id"
    });
    return {
      table,
      extend,
      editFormFields,
      editFormOptions,
      searchFormFields,
      searchFormOptions,
      columns,
      detail
    };
  }
});
</script>
      